An Introduction to Timelink
===========================

Timelink is computer tool specially developed to support micro-historical
research with a strong emphasis on network analysis and prosopography.

Timelink provides a data models and procedures to go from historical
sources to network analysis, convering the transcription of sources,
record linking, reconstitution of biographies and network inference.

Timelink is unique in that it bridges a *source-oriented* approach with
a *person-oriented* approach.

This document provides a quick overview of *Timelink*.

.. contents:: Summary
    :depth: 2



The Problem
-----------

How to reconstruct individual biographies from diverse historical sources and
from those biographies infer networks of relations between people?

Points of interest:

- Few *apriori* choices on who is relevant.
- Focus is on network analysis: relations between people are as important
  as individual attributes.
- Great diversity of sources (anything with personal information can be used).
- Linking references to the same persons in different sources is essential
  (record linking).

Aims
----

Data input close to the original source
+++++++++++++++++++++++++++++++++++++++

- Information about persons should keep the original context, so that at
  latter stages of research each item of information is traceable to the
  original source.
- Original source structure and sequence of information should be preserved
  so that a clear representation of the original sources is possible at
  any moment.
- Decisions implying loss of information should be postponed, requiring an
  expressive and efficient method of data entry.

Late and reversible record linking
++++++++++++++++++++++++++++++++++

- Decision on who is who should be made when all available
  information is available.
- Record linking should be reversible (mistakes happen).

Flexible interface for complex information
++++++++++++++++++++++++++++++++++++++++++

Find ways to show the complex information of biographies and networks
in a comprehensible way.

















